function dh = densityplot (spmat, xmin, varargin)

%DENSITYPLOT  spike density plots based on a spikematrix
%
%    DENSITYPLOT(SPMAT,XMIN) plots the spike density function obtained from
%    the SPMAT spikematrix, and sets XMIN as the starting ms in the chart.
%
%    The smoothing algorithm uses a kernel of given width (in ms) and shape.
%    Currently implemented kernels are 'boxcar', 'gauss', and 'epsp'.
%    By default, the function uses the values stored in giucode.def.
%    One or both parameters, however, can be specified as follows:
%    DENSITYPLOT (SPMAT,XMIN,KERNELWIDTH,KERNELTYPE)
%
%    If either a @cortex object or a @spix object is the first parameter of
%    a DENSITYPLOT call, then the corresponding overloaded function is called
%    first. Click on link below for details.
%
% Last modified: 22 Feb 06

% Released: 22 Feb 06

error (NOTspikematrix(spmat));
error (NOTscalar(xmin));

d = meanfiringdensity (spmat, varargin{:});
xmax = xmin+length(d)-1;
dh = plot (xmin:xmax, d);
ymax = max(10, ceil(max(d)/10)*10);
set (gca, 'xlim', [xmin xmax], 'ylim', [0 ymax]);