function yestrials = trialset (c, k, g)

% TRIALSET   array of trials matching a key
%
% TRIALSET(CO,KEY)  returns an array of trial numbers from the CO
%    @cortex object that match the conditions set by KEY, a single key
%    from a @key object.
%
% Last modified: 20 Nov 04

% 11 May 00: group support added
% 14 Jul 00: fixed a bug that produced an error if the k.trials range
%            exceeded the number of existing trials
% 10 Oct 02: @key support added.
% 10 Nov 04: help text
% 20 Nov 04: expected replaced by given;
%            fixed an old bug in handling k.rept

y = [];
if nargin < 2
   error ('too few arguments')
else
   if ~isa (c, 'cortex')
      %      error ('first argument must be @cortex object');
   end
   s = k.size;
end
switch class (k)
   case 'rules'
      warning ('use of @rules is deprecated; please use @key objects instead');
      if prod(s) == 1
         y = gettrialset (c, k);
      else
         if nargin < 3
            error ('multi-rule object passed using single-rule syntax');
         end
         if g < 1 | g > length (s)
            error ('requested group does not exist');
         end
         for rule = 1:s(g)
            y = [y, gettrialset(c,k(g,rule))];
         end
      end
   case 'key'
      if nargin > 2
         warning ('only two arguments needed; extra args ignored')
      end
      nk = k.size;
      
      if length(nk) > 1
         error ('trialset cannot process more than one key');
      end
      for sk = 1:nk
         y = [y, gettrialset(c,k(1,sk))];
      end
   otherwise
      error ('second argument must be a key (or @rule object)');
end
yestrials = sort (y);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function yest = gettrialset (c, k)

if k.trials ~= -1
   yes = zeros (c.trials, 1);
   its = intersect (1:c.tri, k.trials);
   yes (its) = 1;
else
   yes = ones (length(c.conds), 1);
end

if k.conds ~= -1
   mb = ismember (c.conds, k.conds);
   if ~isempty (mb)
      yes = and (yes, mb);
   end
end

if k.blocks ~= -1
   mb = ismember (c.blocks, k.blocks);
   if ~isempty (mb)
      yes = and (yes, mb);
   end
end

if k.resps ~= -1
   mb = ismember (c.resps, k.resps);
   if ~isempty (mb)
      yes = and (yes, mb);
   end
end

if k.type ~= -1
   mb = ismember (c.type, k.type);
   if ~isempty (mb)
      yes = and (yes, mb);
   end
end

if k.given ~= -1
   mb = ismember (c.given, k.given);
   if ~isempty (mb)
      yes = and (yes, mb);
   end
end

if k.rel ~= -1
   mb = ismember (c.rel, k.rel);
   if ~isempty (mb)
      yes = and (yes, mb);
   end
end

if k.rept ~= -1
   mb = ismember (c.rept, k.rept);
   if ~isempty (mb)
      yes = and (yes, mb);
   end
end

yest = (find(yes))';