function [h b] = stdev (as, varargin)

% @ANNSETUP/STDEV  standard deviation bars on bar charts
%     STDEV(AS,B) adds standard deviation bars on a previously created bar
%     chart based on the AS @annsetup object. B is the array of handles to
%     the barseries returned by BAR(AS).
%
%     STDEV(AS) creates a bar chart from the AS @annsetup object and then
%     adds standard deviation bars.
%
%     STDEV(..., LineSpec)   draws the standard deviation bars using the
%     line type, marker symbol, and color as in errorbar.m
%
%     H=STDEV(...) returns the handles to the errorbarseries objects
%     [H B]=STDEV(...) also returns the barseries handles (useful if STDEV
%     is used to generate the bar chart).
%
%Last modified: 05 Feb 06

if nargin == 1
	% if no hggroup handles are passed, then create a new bar chart
	b = bar (as);
else
	b = varargin{1};
	varargin(1)=[];
	if ishandle(b)
		if ~strcmp (get(b(1), 'type'), 'hggroup')
			error ('invalid argument: handle to barseries expected');
		end
	else
		b = bar (as);
	end
end

if as.N > 2, error ('bar charts of @annsetup objects with more than 2 factors are not supported'); end
[mm, sd, se, gl] = descriptive(as);
h = barerr (horzarray(b), 0, sd, varargin{:});
