function as = addxls (as, varargin)

%@FACTS/ADDXLS adds observations to a @facts object from an Excel table
%
%
%Last modified: 27 Aug 06

% Created on 27 Aug 06

% first retrieve the numerical and text (cell array)
% variables from the .xls file
[dat, lab]=xlsreadvars (varargin{:});

% the list of numerical column headers
df = fieldnames(dat);

% how many data points are there in the first column?
nd = length(dat.(df{1}));

% prepare a NaN matrix to be filled with actual data
td = repmat(NaN, nd, as.X);

assdep=0;

% PARSE DEPENDENT VARIABLES
% for each header of numerical columns in the xls table:
for d=df(:)'
   % is the header among the object's dependent variables?
   s = strmatch(d{1}, as.P, 'exact');
   if isempty(s) % no, it's not, so ignore and warn the user
      if as.verbose
         msg = sprintf ([...
            'The .xls sheet header label %s\n' ...
            'is not a dependent variable in this object\n' ...
            'and will be ignored'], ...
            upper (d{1}));
         disp (msg);
      end
   else % yes, we have a match
      % put the data column into the temp matrix
      td(:,s) = dat.(d{1});
      assdep=assdep+1;
   end
end
% are the assigned data columns fewer than the object's dependents?
if assdep<as.X & as.verbose
   disp ('some of the dependent variables were not assigned');
end
% append temporary matrix to data
as.D = [as.D; td];

% PARSE INDEPENDENT VARIABLES
%
% first check factors

% the list of textual column headers
lf = fieldnames(lab);
% how many labels are there in the first column?
nl = length(lab.(lf{1}));
% is there a mismatch in dep- vs. indep- colum size?
if nl ~= nd
   error ('number of level labels is different from number of observations');
end

assfact = [];

% for each header of textual column in the xls table...
for l=lf(:)'
   % is the header among the object's factor names?
   fs = strmatch(l{1}, as.F, 'exact');
   if isempty(fs) % no, it's not, so ignore and warn the user
      if as.verbose
         msg = sprintf ([...
            'The .xls sheet header label %s\n' ...
            'is not a factor name in this object\n' ...
            'and will be ignored'], ...
            upper (d{1}));
         disp (msg);
      end
   else % yes, we have a match
      %%%%%%%%%%%%%%%%%%%%
      % CHECK LEVEL LABELS
      %%%%%%%%%%%%%%%%%%%%
      % cell array of string values for this textual column
      labs = lab.(l{1});
      % find strings that are NOT (yet) known levels
      sd = setdiff(labs, as.L{fs});
      if ~isempty(sd)
         for i=sd
            newlev = i{1};
            as.L{fs}{end+1} = newlev;
            if as.verbose
               disp (['adding new level "' newlev '" to factor "' as.F{fs} '"']);
            end
         end
      end
      as.G{fs} = [as.G{fs}; lab.(l{1})];
   end
end
