function as = facts (factors, levels, dependents)

%@FACTS/FACTS  the @facts class constructor 
%
%   the @facts object class provides a handy way to accumulate, plot, and
%   analyze data with t-tests and n-way ANOVAs.
%
%   A @facts object is characterized by n factors, each of them represented
%   by any number of levels.
%   
%   work in progress..........
%
%
%   Constructor's syntax: F = FACTS(N)
%   creates and returns a @facts object.
%   N can be either the number of factors in the analysis to be performed,
%   or a cell array containing the names of each factor (recommended).
%
%Last modified: 26 Aug 06

% Last unnoted changes: 02 AUg 03
% 03 Aug 05: factor labeling added to constructor syntax
% 31 Jan 06: verbosity added
% 26 Aug 06: output text commented out


% instance variables of @facts objects, in order of declaration:
% N: scalar, number of factors
% F: cell array, list of factor labels
% L: array of cell arrays, list of level labels
% G: cell array, list of data levels
% X: number of dependent variables
% P: dependent variable labels
% D: double matrix, data
% verbose: verbose flag
% defs:    defaults

if isnumscalar (factors)
   as.N = factors;
	for i=1:as.N
		as.F{i} = sprintf ('factor%02d', i);
	end
elseif iscell (factors)
   as.N = length(factors);
   as.F = factors;
else
   error ('wrong argument type');
end

if nargin > 1
	if ~iscell (levels), error ('LEVELS must be a cell array'); end
	if length (levels) ~= as.N
		error ('LEVELS must have as many cells as there are factors');
	end
	as.L = levels;
else
	as.L = repmat ({[]}, as.N, 1);
end

as.G = repmat ({[]}, as.N, 1);

if nargin>2
   if iscell(dependents)
      as.X = length(dependents);
      as.P = dependents;
   elseif isscalar (dependents)
      as.X = dependents;
      for i=1:as.X
         as.P{i} = sprintf('var%03d', i);
      end
   else
      error ('DEPENDENTS must be either a scalar or a cell array');
   end
else
   as.X = 1;
   as.P = {'data'};
end
as.D = [];

as.verbose = false;
as.defs.factors = 1:as.N;
as.defs.dependent = 1;
as.defs.legend = false;
as = class (as, 'facts');