function out = different (a, b)

%different.m
%
%Syntax: D = DIFFERENT (A, B)
%
%A, B: any two variables, including structures and cell arrays.
%D:    a non-zero value if the two variables are not identical.
%
%if no output variable is specified, a brief message is displayed.
%
%Last modified: 29 apr 2001

res = recident (a, b);
if nargout
    out = res;
else
    switch res
    case 0
        disp ('the two variables are identical');
    case 1
        disp ('different class');
    case 2
        disp ('different number of dimensions');
    case 3
        disp ('different size');
    case 4
        disp ('different number of fields');
    case 5
        disp ('different fields');
    case 6
        disp ('different values');
    end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function res = recident (a, b)

res = 0;
if ~strcmp (class(a), class(b))
    res = 1
    return
end

sa = size(a); sb = size(b);
if length (sa) ~= length(sb)
    res = 2;
    return
end
if any (sa ~= sb)
    res = 3;
    return
end
la = a(:);
lb = b(:);

switch class(a)
%%%%
case 'struct'
    fna = sort (fieldnames (la));
    fnb = sort (fieldnames (lb));
    nna = length (fna);
    if nna ~= length (fnb)
        res = 4;
        return
    end
    for j = 1:length(la)
        for i = 1:nna
            if ~strcmp (fna{i}, fnb{i})
                res = 5;
                return
            end
            ta = getfield (la, fna{i});
            tb = getfield (lb, fna{i});
            res = recident (ta, tb);
            if res, return, end
        end
    end
%%%%    
case 'cell'
    for i = 1:length(la)
        res = recident (la{i}, lb{i});
        if res, return, end
    end
%%%%    
case {'double', 'char', 'sparse', 'int8', 'uint8', ...
      'int16', 'uint16', 'int32', 'uint32'}
    if any (la ~= lb)
        res = 6;
        return
    end
otherwise
    error ('cannot handle this data type')
end