function ho = edgehist (x, edges)

%EDGEHIST   plots histograms based on histc
%
%   EDGEHIST(X,EDGES) produces a histogram plot of the number of values
%   in X that fall between the elements in the EDGES vector (which must
%   contain monotonically non-decreasing values). The first and last
%   elements in EDGES are used to set the axis' xlim.
%
%   EDGEHIST is different from Matlab's built-in HIST in two ways:
%   - as HISTC, it uses bin edges rather than midpoints
%   - it draws a single area rather than separate bars
%
%   H = EDGEHIST(...) also returns a handle to the plotted area object
%
%Last modified: 17 Apr 03

% Since 17 Apr 03:
% 23 Mar 06: help text, small fix, and nargout handling

ed = horzarray(edges);
n = histc (x, ed);
[xx, yy] = stairs (n);
ed = [ed; ed];
h = area (ed(2:end), yy);
set (gca, 'xlim', [ed(1) ed(end)], 'tickdir', 'out');

% the following will work with the bar command
% half = (edges(2)-edges(1))/2;
% bar (edges+half, n)

if nargout, ho=h; end