function g = grayish(s, m)
%GRAYISH   custom grayscale colormap
%   GRAYISH(SIDES) returns a grayscale lookup table where the darkest and
%   lightest gray levels are specified in the 2-element vector SIDES.
%   The start point can be either darker or lighter than the end point.
%   The number of gray levels generated is equal to the length of the
%   current colormap.
%
%   GRAYISH(SIDES,M) returns a lookup table with M gray levels.
%
%   For example: >> map = grayish([.8 .5], 4)
%
% map =
%   0.8    0.8    0.8
%   0.7    0.7    0.7
%   0.6    0.6    0.6
%   0.5    0.5    0.5
%
%   See also HSV, HOT, COOL, BONE, COPPER, PINK, FLAG, 
%   COLORMAP, RGBPLOT.
%
% Last modified: 7 Sep 06

% Created on: 7 Sep 06

if ~isnumvector(s)
   error ('SIDES argument must be a numeric vector');
end
if isscalar(s), s(2) = 1; end
if nargin < 2, m = size(get(gcf,'colormap'),1); end
g = linspace(s(1), s(2), m)';
g = [g g g];