function retmat = permutarray (a, file)
%PERMUTARRAY   permutations of a vector
%
%   P = PERMUTARRAY(A) computes all possible permutations of the values in
%   the vector A and returns P, a matrix in which each row is a particular
%   permutation. 
%
%   PERMUTARRAY(A,FILE) instead of returning the permutation matrix, writes
%   permutations in a tab-delimited text file of name FILE.
%
%   The function uses a cute but very inefficient recursive algorithm; I
%   recommend against using a vector longer than 9 elements if the first
%   syntax is used. If permutations are dumped to file then I guess the
%   limit is your disk capacity. Still very slow to run, though...
%
% Last modified: 09 Mar 06

v = horzarray (a, 'A');
if nargin > 1
	f = openfile (file, 'w');
else
	f = 0;
end
ret = super ([], v, f);
if f, fclose (f); end
if nargout, retmat = ret; end
return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function ar = super (base, dafare, f)

l  = length (dafare);
if l==1
   ar = [base, dafare];
   return
end

ar = [];
for i=1:l
   nb = [base, dafare(i)];
	nd = dafare;
	nd (i) = [];
	nr = super(nb, nd, f);
	if ~isempty(nr)
		if f
			s = sprintf ('%d\t', nr);
			fprintf (f, '%s\n', s(1:end-1));
			ar = [];
		else
			ar = [ar; nr];
		end
	end
end
return