function [dat, lab] = xlsreadvars (varargin)

% XLSREADVARS  reads an Excel table into variables
%
% 26 Aug 06

% start by calling Matlab's xlsread
[num, txt]=xlsread(varargin{:});
head = txt(1,     :);
body = txt(2:end, :);
cols = length(head);

% xlsread's output variable num may contain all-NaN columns
% let us remove those from the matrix
for i=size(num, 2):-1:1
   if all(isnan(num(:, i)))
      num(:, i)=[];
   end
end

% any duplicate header labels?
if cols ~= length(unique(txt(1,:)))
   error ('header labels must be unique');
end

% go through the columns in txt
for i=1:cols
   % if a header label is not a string, then xlsread
   % leaves an empty cell there... raise error
   if isempty(head(i))
      error ('header row must contain valid variable names, ie unique strings');
   end
   
   % if all body cells are empty then
   % this column contains numerical data
   if isempty(char(body{:,i}))
      % add num column to dat output
      dat.(head{i}) = num(:,1);
      num(:,1) = [];
   else
      % add body column to lab output
      lab.(head{i}) = body(:,i);
   end
end

% % is the number of columns thought to contain numerical data
% % different from that actually returned in num?
% if sum(isnum) ~= size(num, 2)
%    error ('variable number mismatch');
% end
% 
% %
% g=0;
% for i=1:cols
%    if nc(i)
%       g=g+1;
%       t = num(:,g);
%    else
%       t = txt(2:end,i);
%    end
%    vn = txt {1,i};
%    if nargout
%       s.(vn) = t;
%    else
%       assignin ('caller', vn, t);
%    end
% end